@@ -1,12 +1,13 @@
 from __future__ import print_function
-import msgpackrpc #install as admin: pip install msgpack-rpc-python
-import numpy as np #pip install numpy
+import msgpackrpc  # install as admin: pip install msgpack-rpc-python
+import numpy as np  # pip install numpy
+
 
 class MsgpackMixin:
 
     """
     """
-    
+
     def __repr__(self):
         """
         
@@ -14,6 +15,7 @@ class MsgpackMixin:
             TYPE: Description
         """
         from pprint import pformat
+
         return "<" + type(self).__name__ + "> " + pformat(vars(self), indent=4, width=1)
 
     def to_msgpack(self, *args, **kwargs):
@@ -39,13 +41,20 @@ class MsgpackMixin:
             TYPE: Description
         """
         obj = cls()
-        #obj.__dict__ = {k.decode('utf-8'): (from_msgpack(v.__class__, v) if hasattr(v, "__dict__") else v) for k, v in encoded.items()}
-        obj.__dict__ = { k : (v if not isinstance(v, dict) else getattr(getattr(obj, k).__class__, "from_msgpack")(v)) for k, v in encoded.items()}
-        #return cls(**msgpack.unpack(encoded))
+        # obj.__dict__ = {k.decode('utf-8'): (from_msgpack(v.__class__, v) if hasattr(v, "__dict__") else v) for k, v in encoded.items()}
+        obj.__dict__ = {
+            k: (
+                v
+                if not isinstance(v, dict)
+                else getattr(getattr(obj, k).__class__, "from_msgpack")(v)
+            )
+            for k, v in encoded.items()
+        }
+        # return cls(**msgpack.unpack(encoded))
         return obj
 
 
-class ImageType:    
+class ImageType:
 
     """
     
@@ -59,7 +68,7 @@ class ImageType:
         Segmentation (int): Description
         SurfaceNormals (int): Description
     """
-    
+
     Scene = 0
     DepthPlanner = 1
     DepthPerspective = 2
@@ -69,6 +78,7 @@ class ImageType:
     SurfaceNormals = 6
     Infrared = 7
 
+
 class DrivetrainType:
 
     """Type of DrivetrainType
@@ -77,10 +87,11 @@ class DrivetrainType:
         ForwardOnly (int): Fixes yaw along tangent of velocity vector (atan2(vy, vx)) 
         MaxDegreeOfFreedom (int): Description
     """
-    
+
     MaxDegreeOfFreedom = 0
     ForwardOnly = 1
-    
+
+
 class LandedState:
 
     """
@@ -89,7 +100,7 @@ class LandedState:
         Flying (int): Description
         Landed (int): Description
     """
-    
+
     Landed = 0
     Flying = 1
 
@@ -105,6 +116,7 @@ class WeatherParameter:
     Fog = 7
     Enabled = 8
 
+
 class Vector3r(MsgpackMixin):
     """
     
@@ -113,12 +125,12 @@ class Vector3r(MsgpackMixin):
         y_val (float): Description
         z_val (float): Description
     """
-    
+
     x_val = 0.0
     y_val = 0.0
     z_val = 0.0
 
-    def __init__(self, x_val = 0.0, y_val = 0.0, z_val = 0.0):
+    def __init__(self, x_val=0.0, y_val=0.0, z_val=0.0):
         """
         
         Args:
@@ -148,7 +160,9 @@ class Vector3r(MsgpackMixin):
         Returns:
             TYPE: Description
         """
-        return Vector3r(self.x_val + other.x_val, self.y_val + other.y_val, self.z_val + other.z_val)
+        return Vector3r(
+            self.x_val + other.x_val, self.y_val + other.y_val, self.z_val + other.z_val
+        )
 
     def __sub__(self, other):
         """
@@ -159,7 +173,9 @@ class Vector3r(MsgpackMixin):
         Returns:
             TYPE: Description
         """
-        return Vector3r(self.x_val - other.x_val, self.y_val - other.y_val, self.z_val - other.z_val)
+        return Vector3r(
+            self.x_val - other.x_val, self.y_val - other.y_val, self.z_val - other.z_val
+        )
 
     def __truediv__(self, other):
         """
@@ -173,10 +189,19 @@ class Vector3r(MsgpackMixin):
         Raises:
             TypeError: Description
         """
-        if type(other) in [int, float] + np.sctypes['int'] + np.sctypes['uint'] + np.sctypes['float']:
-            return Vector3r( self.x_val / other, self.y_val / other, self.z_val / other)
-        else: 
-            raise TypeError('unsupported operand type(s) for /: %s and %s' % ( str(type(self)), str(type(other))) )
+        if (
+            type(other)
+            in [int, float]
+            + np.sctypes["int"]
+            + np.sctypes["uint"]
+            + np.sctypes["float"]
+        ):
+            return Vector3r(self.x_val / other, self.y_val / other, self.z_val / other)
+        else:
+            raise TypeError(
+                "unsupported operand type(s) for /: %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def __mul__(self, other):
         """
@@ -190,10 +215,19 @@ class Vector3r(MsgpackMixin):
         Raises:
             TypeError: Description
         """
-        if type(other) in [int, float] + np.sctypes['int'] + np.sctypes['uint'] + np.sctypes['float']:
-            return Vector3r(self.x_val*other, self.y_val*other, self.z_val*other)
-        else: 
-            raise TypeError('unsupported operand type(s) for *: %s and %s' % ( str(type(self)), str(type(other))) )
+        if (
+            type(other)
+            in [int, float]
+            + np.sctypes["int"]
+            + np.sctypes["uint"]
+            + np.sctypes["float"]
+        ):
+            return Vector3r(self.x_val * other, self.y_val * other, self.z_val * other)
+        else:
+            raise TypeError(
+                "unsupported operand type(s) for *: %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def dot(self, other):
         """
@@ -208,9 +242,16 @@ class Vector3r(MsgpackMixin):
             TypeError: Description
         """
         if type(self) == type(other):
-            return self.x_val*other.x_val + self.y_val*other.y_val + self.z_val*other.z_val
+            return (
+                self.x_val * other.x_val
+                + self.y_val * other.y_val
+                + self.z_val * other.z_val
+            )
         else:
-            raise TypeError('unsupported operand type(s) for \'dot\': %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for 'dot': %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def cross(self, other):
         """
@@ -228,7 +269,10 @@ class Vector3r(MsgpackMixin):
             cross_product = np.cross(self.to_numpy_array(), other.to_numpy_array())
             return Vector3r(cross_product[0], cross_product[1], cross_product[2])
         else:
-            raise TypeError('unsupported operand type(s) for \'cross\': %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for 'cross': %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def get_length(self):
         """
@@ -236,7 +280,7 @@ class Vector3r(MsgpackMixin):
         Returns:
             TYPE: Description
         """
-        return ( self.x_val**2 + self.y_val**2 + self.z_val**2 )**0.5
+        return (self.x_val ** 2 + self.y_val ** 2 + self.z_val ** 2) ** 0.5
 
     def distance_to(self, other):
         """
@@ -247,7 +291,11 @@ class Vector3r(MsgpackMixin):
         Returns:
             TYPE: Description
         """
-        return ( (self.x_val-other.x_val)**2 + (self.y_val-other.y_val)**2 + (self.z_val-other.z_val)**2 )**0.5
+        return (
+            (self.x_val - other.x_val) ** 2
+            + (self.y_val - other.y_val) ** 2
+            + (self.z_val - other.z_val) ** 2
+        ) ** 0.5
 
     def to_Quaternionr(self):
         """
@@ -275,13 +323,13 @@ class Quaternionr(MsgpackMixin):
         y_val (float): Description
         z_val (float): Description
     """
-    
+
     w_val = 0.0
     x_val = 0.0
     y_val = 0.0
     z_val = 0.0
 
-    def __init__(self, x_val = 0.0, y_val = 0.0, z_val = 0.0, w_val = 1.0):
+    def __init__(self, x_val=0.0, y_val=0.0, z_val=0.0, w_val=1.0):
         """
         
         Args:
@@ -317,9 +365,17 @@ class Quaternionr(MsgpackMixin):
             TypeError: Description
         """
         if type(self) == type(other):
-            return Quaternionr( self.x_val+other.x_val, self.y_val+other.y_val, self.z_val+other.z_val, self.w_val+other.w_val )
+            return Quaternionr(
+                self.x_val + other.x_val,
+                self.y_val + other.y_val,
+                self.z_val + other.z_val,
+                self.w_val + other.w_val,
+            )
         else:
-            raise TypeError('unsupported operand type(s) for +: %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for +: %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def __mul__(self, other):
         """
@@ -336,14 +392,19 @@ class Quaternionr(MsgpackMixin):
         if type(self) == type(other):
             t, x, y, z = self.w_val, self.x_val, self.y_val, self.z_val
             a, b, c, d = other.w_val, other.x_val, other.y_val, other.z_val
-            return Quaternionr( w_val = a*t - b*x - c*y - d*z,
-                                x_val = b*t + a*x + d*y - c*z,
-                                y_val = c*t + a*y + b*z - d*x,
-                                z_val = d*t + z*a + c*x - b*y)
+            return Quaternionr(
+                w_val=a * t - b * x - c * y - d * z,
+                x_val=b * t + a * x + d * y - c * z,
+                y_val=c * t + a * y + b * z - d * x,
+                z_val=d * t + z * a + c * x - b * y,
+            )
         else:
-            raise TypeError('unsupported operand type(s) for *: %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for *: %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
-    def __truediv__(self, other): 
+    def __truediv__(self, other):
         """
         
         Args:
@@ -355,12 +416,26 @@ class Quaternionr(MsgpackMixin):
         Raises:
             TypeError: Description
         """
-        if type(other) == type(self): 
+        if type(other) == type(self):
             return self * other.inverse()
-        elif type(other) in [int, float] + np.sctypes['int'] + np.sctypes['uint'] + np.sctypes['float']:
-            return Quaternionr( self.x_val / other, self.y_val / other, self.z_val / other, self.w_val / other)
-        else: 
-            raise TypeError('unsupported operand type(s) for /: %s and %s' % ( str(type(self)), str(type(other))) )
+        elif (
+            type(other)
+            in [int, float]
+            + np.sctypes["int"]
+            + np.sctypes["uint"]
+            + np.sctypes["float"]
+        ):
+            return Quaternionr(
+                self.x_val / other,
+                self.y_val / other,
+                self.z_val / other,
+                self.w_val / other,
+            )
+        else:
+            raise TypeError(
+                "unsupported operand type(s) for /: %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def dot(self, other):
         """
@@ -375,9 +450,17 @@ class Quaternionr(MsgpackMixin):
             TypeError: Description
         """
         if type(self) == type(other):
-            return self.x_val*other.x_val + self.y_val*other.y_val + self.z_val*other.z_val + self.w_val*other.w_val
+            return (
+                self.x_val * other.x_val
+                + self.y_val * other.y_val
+                + self.z_val * other.z_val
+                + self.w_val * other.w_val
+            )
         else:
-            raise TypeError('unsupported operand type(s) for \'dot\': %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for 'dot': %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def cross(self, other):
         """
@@ -394,7 +477,10 @@ class Quaternionr(MsgpackMixin):
         if type(self) == type(other):
             return (self * other - other * self) / 2
         else:
-            raise TypeError('unsupported operand type(s) for \'cross\': %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for 'cross': %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def outer_product(self, other):
         """
@@ -409,9 +495,12 @@ class Quaternionr(MsgpackMixin):
             TypeError: Description
         """
         if type(self) == type(other):
-            return ( self.inverse()*other - other.inverse()*self ) / 2
+            return (self.inverse() * other - other.inverse() * self) / 2
         else:
-            raise TypeError('unsupported operand type(s) for \'outer_product\': %s and %s' % ( str(type(self)), str(type(other))) )
+            raise TypeError(
+                "unsupported operand type(s) for 'outer_product': %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def rotate(self, other):
         """
@@ -427,12 +516,15 @@ class Quaternionr(MsgpackMixin):
             ValueError: Description
         """
         if type(self) == type(other):
-            if abs(other.get_length() - 1) <= 0.01 :
+            if abs(other.get_length() - 1) <= 0.01:
                 return other * self * other.inverse()
             else:
-                raise ValueError('length of the other Quaternionr must be 1')
+                raise ValueError("length of the other Quaternionr must be 1")
         else:
-            raise TypeError('unsupported operand type(s) for \'rotate\': %s and %s' % ( str(type(self)), str(type(other))) )        
+            raise TypeError(
+                "unsupported operand type(s) for 'rotate': %s and %s"
+                % (str(type(self)), str(type(other)))
+            )
 
     def conjugate(self):
         """
@@ -464,7 +556,7 @@ class Quaternionr(MsgpackMixin):
         Returns:
             TYPE: Description
         """
-        return self/self.get_length()
+        return self / self.get_length()
 
     def get_length(self):
         """
@@ -472,7 +564,9 @@ class Quaternionr(MsgpackMixin):
         Returns:
             float: norm of quaternion
         """
-        return ( self.x_val**2 + self.y_val**2 + self.z_val**2 + self.w_val**2 )**0.5
+        return (
+            self.x_val ** 2 + self.y_val ** 2 + self.z_val ** 2 + self.w_val ** 2
+        ) ** 0.5
 
     def to_numpy_array(self):
         """
@@ -480,7 +574,9 @@ class Quaternionr(MsgpackMixin):
         Returns:
             np.array: Description
         """
-        return np.array([self.x_val, self.y_val, self.z_val, self.w_val], dtype=np.float32)
+        return np.array(
+            [self.x_val, self.y_val, self.z_val, self.w_val], dtype=np.float32
+        )
 
 
 class Pose(MsgpackMixin):
@@ -490,11 +586,11 @@ class Pose(MsgpackMixin):
         orientation (Quaternionr): Description
         position (Vector3r): Description
     """
-    
+
     position = Vector3r()
     orientation = Quaternionr()
 
-    def __init__(self, position_val = Vector3r(), orientation_val = Quaternionr()):
+    def __init__(self, position_val=Vector3r(), orientation_val=Quaternionr()):
         """
         
         Args:
@@ -513,6 +609,7 @@ class Pose(MsgpackMixin):
         """
         return Pose(Vector3r.nanVector3r(), Quaternionr.nanQuaternionr())
 
+
 class CollisionInfo(MsgpackMixin):
     """
     
@@ -526,7 +623,7 @@ class CollisionInfo(MsgpackMixin):
         position (TYPE): Description
         time_stamp (float): Description
     """
-    
+
     has_collided = False
     normal = Vector3r()
     impact_point = Vector3r()
@@ -536,6 +633,7 @@ class CollisionInfo(MsgpackMixin):
     object_name = ""
     object_id = -1
 
+
 class GeoPoint(MsgpackMixin):
     """
     
@@ -544,11 +642,12 @@ class GeoPoint(MsgpackMixin):
         latitude (float): Description
         longitude (float): Description
     """
-    
+
     latitude = 0.0
     longitude = 0.0
     altitude = 0.0
 
+
 class YawMode(MsgpackMixin):
     """
     Struct YawMode with two fields, yaw_or_rate and is_rate. 
@@ -573,11 +672,11 @@ class YawMode(MsgpackMixin):
                         if False, yaw_or_rate is interpreted as angles in **degrees**,
         yaw_or_rate (float): value of desired yaw rate, or desired yaw angle. Interpretation depends upon is_rate
     """
-    
+
     is_rate = True
     yaw_or_rate = 0.0
 
-    def __init__(self, is_rate = True, yaw_or_rate = 0.0):
+    def __init__(self, is_rate=True, yaw_or_rate=0.0):
         """
         
         Args:
@@ -587,6 +686,7 @@ class YawMode(MsgpackMixin):
         self.is_rate = is_rate
         self.yaw_or_rate = yaw_or_rate
 
+
 class RCData(MsgpackMixin):
 
     """
@@ -608,15 +708,32 @@ class RCData(MsgpackMixin):
         timestamp (int): Description
         yaw (TYPE): Description
     """
-    
+
     timestamp = 0
-    pitch, roll, throttle, yaw = (0.0,)*4 #init 4 variable to 0.0
-    switch1, switch2, switch3, switch4 = (0,)*4
-    switch5, switch6, switch7, switch8 = (0,)*4
+    pitch, roll, throttle, yaw = (0.0,) * 4  # init 4 variable to 0.0
+    switch1, switch2, switch3, switch4 = (0,) * 4
+    switch5, switch6, switch7, switch8 = (0,) * 4
     is_initialized = False
     is_valid = False
-    def __init__(self, timestamp = 0, pitch = 0.0, roll = 0.0, throttle = 0.0, yaw = 0.0, switch1 = 0,
-                 switch2 = 0, switch3 = 0, switch4 = 0, switch5 = 0, switch6 = 0, switch7 = 0, switch8 = 0, is_initialized = False, is_valid = False):
+
+    def __init__(
+        self,
+        timestamp=0,
+        pitch=0.0,
+        roll=0.0,
+        throttle=0.0,
+        yaw=0.0,
+        switch1=0,
+        switch2=0,
+        switch3=0,
+        switch4=0,
+        switch5=0,
+        switch6=0,
+        switch7=0,
+        switch8=0,
+        is_initialized=False,
+        is_valid=False,
+    ):
         """
         
         Args:
@@ -637,21 +754,22 @@ class RCData(MsgpackMixin):
             is_valid (bool, optional): Description
         """
         self.timestamp = timestamp
-        self.pitch = pitch 
+        self.pitch = pitch
         self.roll = roll
-        self.throttle = throttle 
-        self.yaw = yaw 
-        self.switch1 = switch1 
-        self.switch2 = switch2 
-        self.switch3 = switch3 
-        self.switch4 = switch4 
+        self.throttle = throttle
+        self.yaw = yaw
+        self.switch1 = switch1
+        self.switch2 = switch2
+        self.switch3 = switch3
+        self.switch4 = switch4
         self.switch5 = switch5
-        self.switch6 = switch6 
-        self.switch7 = switch7 
-        self.switch8 = switch8 
+        self.switch6 = switch6
+        self.switch7 = switch7
+        self.switch8 = switch8
         self.is_initialized = is_initialized
         self.is_valid = is_valid
 
+
 class ImageRequest(MsgpackMixin):
     """
     
@@ -661,13 +779,13 @@ class ImageRequest(MsgpackMixin):
         image_type (TYPE): Description
         pixels_as_float (bool): Description
     """
-    
-    camera_name = '0'
+
+    camera_name = "0"
     image_type = ImageType.Scene
     pixels_as_float = False
     compress = False
 
-    def __init__(self, camera_name, image_type, pixels_as_float = False, compress = True):
+    def __init__(self, camera_name, image_type, pixels_as_float=False, compress=True):
         """
         
         Args:
@@ -699,19 +817,20 @@ class ImageResponse(MsgpackMixin):
         time_stamp (TYPE): Description
         width (int): Description
     """
-    
+
     image_data_uint8 = np.uint8(0)
     image_data_float = 0.0
     camera_position = Vector3r()
     camera_orientation = Quaternionr()
     time_stamp = np.uint64(0)
-    message = ''
+    message = ""
     pixels_as_float = 0.0
     compress = True
     width = 0
     height = 0
     image_type = ImageType.Scene
 
+
 class CarControls(MsgpackMixin):
     throttle = 0.0
     steering = 0.0
@@ -721,8 +840,16 @@ class CarControls(MsgpackMixin):
     manual_gear = 0
     gear_immediate = True
 
-    def __init__(self, throttle = 0, steering = 0, brake = 0,
-        handbrake = False, is_manual_gear = False, manual_gear = 0, gear_immediate = True):
+    def __init__(
+        self,
+        throttle=0,
+        steering=0,
+        brake=0,
+        handbrake=False,
+        is_manual_gear=False,
+        manual_gear=0,
+        gear_immediate=True,
+    ):
         self.throttle = throttle
         self.steering = steering
         self.brake = brake
@@ -731,16 +858,16 @@ class CarControls(MsgpackMixin):
         self.manual_gear = manual_gear
         self.gear_immediate = gear_immediate
 
-
     def set_throttle(self, throttle_val, forward):
-        if (forward):
+        if forward:
             self.is_manual_gear = False
             self.manual_gear = 0
             self.throttle = abs(throttle_val)
         else:
             self.is_manual_gear = False
             self.manual_gear = -1
-            self.throttle = - abs(throttle_val)
+            self.throttle = -abs(throttle_val)
+
 
 class KinematicsState(MsgpackMixin):
     """
@@ -753,7 +880,7 @@ class KinematicsState(MsgpackMixin):
         orientation (Quaternionr): Description
         position (Vector3r): Description
     """
-    
+
     position = Vector3r()
     orientation = Quaternionr()
     linear_velocity = Vector3r()
@@ -761,6 +888,7 @@ class KinematicsState(MsgpackMixin):
     linear_acceleration = Vector3r()
     angular_acceleration = Vector3r()
 
+
 class EnvironmentState(MsgpackMixin):
     position = Vector3r()
     geo_point = GeoPoint()
@@ -769,6 +897,7 @@ class EnvironmentState(MsgpackMixin):
     temperature = 0.0
     air_density = 0.0
 
+
 class CarState(MsgpackMixin):
     speed = 0.0
     gear = 0
@@ -779,6 +908,7 @@ class CarState(MsgpackMixin):
     kinematics_estimated = KinematicsState()
     timestamp = np.uint64(0)
 
+
 class MultirotorState(MsgpackMixin):
     """
     
@@ -790,23 +920,25 @@ class MultirotorState(MsgpackMixin):
         rc_data (RCData): Description
         timestamp (np.uint64): Description
     """
-    
-    collision = CollisionInfo();
+
+    collision = CollisionInfo()
     kinematics_estimated = KinematicsState()
     gps_location = GeoPoint()
     timestamp = np.uint64(0)
     landed_state = LandedState.Landed
     rc_data = RCData()
 
+
 class ProjectionMatrix(MsgpackMixin):
     """
     
     Attributes:
         matrix (list): Description
     """
-    
+
     matrix = []
 
+
 class CameraInfo(MsgpackMixin):
     """
     
@@ -815,39 +947,45 @@ class CameraInfo(MsgpackMixin):
         pose (TYPE): Description
         proj_mat (TYPE): Description
     """
-    
+
     pose = Pose()
     fov = -1
     proj_mat = ProjectionMatrix()
 
+
 class LidarData(MsgpackMixin):
     point_cloud = 0.0
     time_stamp = np.uint64(0)
     pose = Pose()
 
+
 class ImuData(MsgpackMixin):
     time_stamp = np.uint64(0)
     orientation = Quaternionr()
     angular_velocity = Vector3r()
     linear_acceleration = Vector3r()
 
+
 class BarometerData(MsgpackMixin):
     time_stamp = np.uint64(0)
     altitude = Quaternionr()
     pressure = Vector3r()
     qnh = Vector3r()
 
+
 class MagnetometerData(MsgpackMixin):
     time_stamp = np.uint64(0)
     magnetic_field_body = Vector3r()
     magnetic_field_covariance = 0.0
 
+
 class GnssFixType(MsgpackMixin):
     GNSS_FIX_NO_FIX = 0
     GNSS_FIX_TIME_ONLY = 1
     GNSS_FIX_2D_FIX = 2
     GNSS_FIX_3D_FIX = 3
 
+
 class GnssReport(MsgpackMixin):
     geo_point = GeoPoint()
     eph = 0.0
@@ -856,11 +994,13 @@ class GnssReport(MsgpackMixin):
     fix_type = GnssFixType()
     time_utc = np.uint64(0)
 
+
 class GpsData(MsgpackMixin):
     time_stamp = np.uint64(0)
     gnss = GnssReport()
     is_valid = False
 
+
 class DistanceSensorData(MsgpackMixin):
     time_stamp = np.uint64(0)
     distance = Quaternionr()
@@ -868,7 +1008,8 @@ class DistanceSensorData(MsgpackMixin):
     max_distance = Quaternionr()
     relative_pose = Pose()
 
-class PIDGains():
+
+class PIDGains:
     """
     Struct to store values of PID gains. Used to transmit controller gain values while instantiating
     AngleLevel/AngleRate/Velocity/PositionControllerGains objects.
@@ -878,6 +1019,7 @@ class PIDGains():
         kI (float): Integrator gain
         kD (float): Derivative gain
     """
+
     def __init__(self, kp, ki, kd):
         self.kp = kp
         self.ki = ki
@@ -886,7 +1028,8 @@ class PIDGains():
     def to_list(self):
         return [self.kp, self.ki, self.kd]
 
-class AngleRateControllerGains():
+
+class AngleRateControllerGains:
     """
     Struct to contain controller gains used by angle level PID controller
     
@@ -895,17 +1038,26 @@ class AngleRateControllerGains():
         pitch_gains (PIDGains): kP, kI, kD for pitch axis
         yaw_gains (PIDGains): kP, kI, kD for yaw axis
     """
-    def __init__(self, roll_gains = PIDGains(0.25, 0, 0),
-                       pitch_gains = PIDGains(0.25, 0, 0),
-                       yaw_gains = PIDGains(0.25, 0, 0)):
+
+    def __init__(
+        self,
+        roll_gains=PIDGains(0.25, 0, 0),
+        pitch_gains=PIDGains(0.25, 0, 0),
+        yaw_gains=PIDGains(0.25, 0, 0),
+    ):
         self.roll_gains = roll_gains
         self.pitch_gains = pitch_gains
         self.yaw_gains = yaw_gains
-    
-    def to_lists(self):
-        return [self.roll_gains.kp, self.pitch_gains.kp, self.yaw_gains.kp], [self.roll_gains.ki, self.pitch_gains.ki, self.yaw_gains.ki], [self.roll_gains.kd, self.pitch_gains.kd, self.yaw_gains.kd]
 
-class AngleLevelControllerGains():
+    def to_lists(self):
+        return (
+            [self.roll_gains.kp, self.pitch_gains.kp, self.yaw_gains.kp],
+            [self.roll_gains.ki, self.pitch_gains.ki, self.yaw_gains.ki],
+            [self.roll_gains.kd, self.pitch_gains.kd, self.yaw_gains.kd],
+        )
+
+
+class AngleLevelControllerGains:
     """
     Struct to contain controller gains used by angle rate PID controller
     
@@ -914,17 +1066,26 @@ class AngleLevelControllerGains():
         pitch_gains (PIDGains): kP, kI, kD for pitch axis
         yaw_gains (PIDGains): kP, kI, kD for yaw axis
     """
-    def __init__(self, roll_gains = PIDGains(2.5, 0, 0),
-                       pitch_gains = PIDGains(2.5, 0, 0),
-                       yaw_gains = PIDGains(2.5, 0, 0)):
+
+    def __init__(
+        self,
+        roll_gains=PIDGains(2.5, 0, 0),
+        pitch_gains=PIDGains(2.5, 0, 0),
+        yaw_gains=PIDGains(2.5, 0, 0),
+    ):
         self.roll_gains = roll_gains
         self.pitch_gains = pitch_gains
         self.yaw_gains = yaw_gains
-    
-    def to_lists(self):
-        return [self.roll_gains.kp, self.pitch_gains.kp, self.yaw_gains.kp], [self.roll_gains.ki, self.pitch_gains.ki, self.yaw_gains.ki], [self.roll_gains.kd, self.pitch_gains.kd, self.yaw_gains.kd]
 
-class VelocityControllerGains():
+    def to_lists(self):
+        return (
+            [self.roll_gains.kp, self.pitch_gains.kp, self.yaw_gains.kp],
+            [self.roll_gains.ki, self.pitch_gains.ki, self.yaw_gains.ki],
+            [self.roll_gains.kd, self.pitch_gains.kd, self.yaw_gains.kd],
+        )
+
+
+class VelocityControllerGains:
     """
     Struct to contain controller gains used by velocity PID controller
     
@@ -933,17 +1094,26 @@ class VelocityControllerGains():
         y_gains (PIDGains): kP, kI, kD for Y axis
         z_gains (PIDGains): kP, kI, kD for Z axis
     """
-    def __init__(self, x_gains = PIDGains(0.2, 0, 0),
-                       y_gains = PIDGains(0.2, 0, 0),
-                       z_gains = PIDGains(2.0, 2.0, 0)):
+
+    def __init__(
+        self,
+        x_gains=PIDGains(0.2, 0, 0),
+        y_gains=PIDGains(0.2, 0, 0),
+        z_gains=PIDGains(2.0, 2.0, 0),
+    ):
         self.x_gains = x_gains
         self.y_gains = y_gains
         self.z_gains = z_gains
-    
-    def to_lists(self):
-        return [self.x_gains.kp, self.y_gains.kp, self.z_gains.kp], [self.x_gains.ki, self.y_gains.ki, self.z_gains.ki], [self.x_gains.kd, self.y_gains.kd, self.z_gains.kd]
 
-class PositionControllerGains():
+    def to_lists(self):
+        return (
+            [self.x_gains.kp, self.y_gains.kp, self.z_gains.kp],
+            [self.x_gains.ki, self.y_gains.ki, self.z_gains.ki],
+            [self.x_gains.kd, self.y_gains.kd, self.z_gains.kd],
+        )
+
+
+class PositionControllerGains:
     """
     Struct to contain controller gains used by position PID controller
     
@@ -952,17 +1122,26 @@ class PositionControllerGains():
         y_gains (PIDGains): kP, kI, kD for Y axis
         z_gains (PIDGains): kP, kI, kD for Z axis
     """
-    def __init__(self, x_gains = PIDGains(0.25, 0, 0),
-                       y_gains = PIDGains(0.25, 0, 0),
-                       z_gains = PIDGains(0.25, 0, 0)):
+
+    def __init__(
+        self,
+        x_gains=PIDGains(0.25, 0, 0),
+        y_gains=PIDGains(0.25, 0, 0),
+        z_gains=PIDGains(0.25, 0, 0),
+    ):
         self.x_gains = x_gains
         self.y_gains = y_gains
         self.z_gains = z_gains
-    
-    def to_lists(self):
-        return [self.x_gains.kp, self.y_gains.kp, self.z_gains.kp], [self.x_gains.ki, self.y_gains.ki, self.z_gains.ki], [self.x_gains.kd, self.y_gains.kd, self.z_gains.kd]
 
-class TrajectoryTrackerGains():
+    def to_lists(self):
+        return (
+            [self.x_gains.kp, self.y_gains.kp, self.z_gains.kp],
+            [self.x_gains.ki, self.y_gains.ki, self.z_gains.ki],
+            [self.x_gains.kd, self.y_gains.kd, self.z_gains.kd],
+        )
+
+
+class TrajectoryTrackerGains:
     """
     Struct to contain trajectory tracker gains used by the pure pursuit controller for moveBySpline and moveBySplineVelConstraints
     
@@ -982,22 +1161,24 @@ class TrajectoryTrackerGains():
         kp_yaw (float): P gain for yaw error
         kd_yaw (float): D gain for yaw error
     """
-    
-    def __init__(self,
-                kp_cross_track = 7.5, 
-                kd_cross_track = 0.0, 
-                kp_vel_cross_track = 5.0, 
-                kd_vel_cross_track = 0.0, 
-                kp_along_track = 0.4, 
-                kd_along_track = 0.0, 
-                kp_vel_along_track = 0.04, 
-                kd_vel_along_track = 0.0, 
-                kp_z_track = 2.0, 
-                kd_z_track = 0.0, 
-                kp_vel_z = 0.4, 
-                kd_vel_z = 0.0, 
-                kp_yaw = 3.0, 
-                kd_yaw = 0.1):
+
+    def __init__(
+        self,
+        kp_cross_track=7.5,
+        kd_cross_track=0.0,
+        kp_vel_cross_track=5.0,
+        kd_vel_cross_track=0.0,
+        kp_along_track=0.4,
+        kd_along_track=0.0,
+        kp_vel_along_track=0.04,
+        kd_vel_along_track=0.0,
+        kp_z_track=2.0,
+        kd_z_track=0.0,
+        kp_vel_z=0.4,
+        kd_vel_z=0.0,
+        kp_yaw=3.0,
+        kd_yaw=0.1,
+    ):
         self.kp_cross_track = kp_cross_track
         self.kd_cross_track = kd_cross_track
         self.kp_vel_cross_track = kp_vel_cross_track
@@ -1020,13 +1201,28 @@ class TrajectoryTrackerGains():
         Returns:
             list[float]: Description
         """
-        return [self.kp_cross_track, self.kd_cross_track, self.kp_vel_cross_track, self.kd_vel_cross_track, 
-                self.kp_along_track, self.kd_along_track, self.kp_vel_along_track, self.kd_vel_along_track, 
-                self.kp_z_track, self.kd_z_track, self.kp_vel_z, self.kd_vel_z, self.kp_yaw, self.kd_yaw]
+        return [
+            self.kp_cross_track,
+            self.kd_cross_track,
+            self.kp_vel_cross_track,
+            self.kd_vel_cross_track,
+            self.kp_along_track,
+            self.kd_along_track,
+            self.kp_vel_along_track,
+            self.kd_vel_along_track,
+            self.kp_z_track,
+            self.kd_z_track,
+            self.kp_vel_z,
+            self.kd_vel_z,
+            self.kp_yaw,
+            self.kd_yaw,
+        ]
+
 
 class MeshPositionVertexBuffersResponse(MsgpackMixin):
     position = Vector3r()
     orientation = Quaternionr()
     vertices = 0.0
     indices = 0.0
-    name = ''
+    name = ""
+
